==> jc-1.4.0.tar.gz: polyglot/visit/PrettyPrinter.h <==
// public class polyglot.visit.PrettyPrinter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9b5998bb4b90b099 polyglot_visit_PrettyPrinter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_PrettyPrinter_H_
#define _JC_polyglot_visit_PrettyPrinter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_CodeWriter$object;

// Typedefs
typedef struct _jc_polyglot_visit_PrettyPrinter$sub_refs	_jc_polyglot_visit_PrettyPrinter$sub_refs;
typedef struct _jc_polyglot_visit_PrettyPrinter$sub_nonrefs	_jc_polyglot_visit_PrettyPrinter$sub_nonrefs;
typedef struct _jc_polyglot_visit_PrettyPrinter$refs	_jc_polyglot_visit_PrettyPrinter$refs;
typedef struct _jc_polyglot_visit_PrettyPrinter$nonrefs	_jc_polyglot_visit_PrettyPrinter$nonrefs;
typedef struct _jc_polyglot_visit_PrettyPrinter$object	_jc_polyglot_visit_PrettyPrinter$object;

typedef const struct _jc_polyglot_visit_PrettyPrinter$vmethods	_jc_polyglot_visit_PrettyPrinter$vmethods;
typedef const struct _jc_polyglot_visit_PrettyPrinter$vtable	_jc_polyglot_visit_PrettyPrinter$vtable;
typedef const struct _jc_polyglot_visit_PrettyPrinter$vtype	_jc_polyglot_visit_PrettyPrinter$vtype;

// Constructors
extern void _jc_polyglot_visit_PrettyPrinter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *);

// Virtual methods
extern jboolean _jc_polyglot_visit_PrettyPrinter$method$appendSemicolon$ef52943abec52244(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *);
extern jboolean _jc_polyglot_visit_PrettyPrinter$method$appendSemicolon$3eee72f89e285cad(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, jboolean);
extern void _jc_polyglot_visit_PrettyPrinter$method$print$be8fd119cbff90e9(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *);
extern void _jc_polyglot_visit_PrettyPrinter$method$printAst$501fe41e7ed32dd4(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *);
extern jboolean _jc_polyglot_visit_PrettyPrinter$method$printType$a652b156b81ce22a(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *);
extern jboolean _jc_polyglot_visit_PrettyPrinter$method$printType$9f92289ce5818d49(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$appendSemicolon$ef52943abec52244;
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$appendSemicolon$3eee72f89e285cad;
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$print$be8fd119cbff90e9;
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$printAst$501fe41e7ed32dd4;
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$printType$a652b156b81ce22a;
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$printType$9f92289ce5818d49;

// Virtual methods structure
struct _jc_polyglot_visit_PrettyPrinter$vmethods {
	jboolean	(*appendSemicolon$ef52943abec52244)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *);
	jboolean	(*appendSemicolon$3eee72f89e285cad)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, jboolean);
	void	(*print$be8fd119cbff90e9)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *);
	void	(*printAst$501fe41e7ed32dd4)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *);
	jboolean	(*printType$a652b156b81ce22a)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *);
	jboolean	(*printType$9f92289ce5818d49)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, jboolean);
};

// Vtable
struct _jc_polyglot_visit_PrettyPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_PrettyPrinter$vmethods	polyglot_visit_PrettyPrinter;
};

// Vtype
struct _jc_polyglot_visit_PrettyPrinter$vtype {
	_jc_type			type;
	_jc_polyglot_visit_PrettyPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_PrettyPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_PrettyPrinter$refs {
    _jc_polyglot_visit_PrettyPrinter$sub_refs	polyglot_visit_PrettyPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_PrettyPrinter$sub_nonrefs {
	jboolean	appendSemicolon;
	jboolean	printType;
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_PrettyPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_PrettyPrinter$sub_nonrefs	polyglot_visit_PrettyPrinter;
};

// Object instance structure
struct _jc_polyglot_visit_PrettyPrinter$object {
	_jc_polyglot_visit_PrettyPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_PrettyPrinter$vtype	*vtype;
	_jc_polyglot_visit_PrettyPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_PrettyPrinter$vtype _jc_polyglot_visit_PrettyPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_PrettyPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_PrettyPrinter$class_object;

#endif	/* _JC_polyglot_visit_PrettyPrinter_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/PrettyPrinter.h <==
// public class polyglot.visit.PrettyPrinter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9b5998bb4b90b099 polyglot_visit_PrettyPrinter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_PrettyPrinter_H_
#define _JC_polyglot_visit_PrettyPrinter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_CodeWriter$object;

// Typedefs
typedef struct _jc_polyglot_visit_PrettyPrinter$sub_refs	_jc_polyglot_visit_PrettyPrinter$sub_refs;
typedef struct _jc_polyglot_visit_PrettyPrinter$sub_nonrefs	_jc_polyglot_visit_PrettyPrinter$sub_nonrefs;
typedef struct _jc_polyglot_visit_PrettyPrinter$refs	_jc_polyglot_visit_PrettyPrinter$refs;
typedef struct _jc_polyglot_visit_PrettyPrinter$nonrefs	_jc_polyglot_visit_PrettyPrinter$nonrefs;
typedef struct _jc_polyglot_visit_PrettyPrinter$object	_jc_polyglot_visit_PrettyPrinter$object;

typedef const struct _jc_polyglot_visit_PrettyPrinter$vmethods	_jc_polyglot_visit_PrettyPrinter$vmethods;
typedef const struct _jc_polyglot_visit_PrettyPrinter$vtable	_jc_polyglot_visit_PrettyPrinter$vtable;
typedef const struct _jc_polyglot_visit_PrettyPrinter$vtype	_jc_polyglot_visit_PrettyPrinter$vtype;

// Constructors
extern void _jc_polyglot_visit_PrettyPrinter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_visit_PrettyPrinter$method$appendSemicolon$ef52943abec52244(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_visit_PrettyPrinter$method$appendSemicolon$3eee72f89e285cad(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_polyglot_visit_PrettyPrinter$method$print$be8fd119cbff90e9(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_visit_PrettyPrinter$method$printAst$501fe41e7ed32dd4(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_visit_PrettyPrinter$method$printType$a652b156b81ce22a(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_visit_PrettyPrinter$method$printType$9f92289ce5818d49(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$appendSemicolon$ef52943abec52244;
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$appendSemicolon$3eee72f89e285cad;
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$print$be8fd119cbff90e9;
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$printAst$501fe41e7ed32dd4;
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$printType$a652b156b81ce22a;
extern _jc_method _jc_polyglot_visit_PrettyPrinter$method_info$printType$9f92289ce5818d49;

// Virtual methods structure
struct _jc_polyglot_visit_PrettyPrinter$vmethods {
	jboolean	(*appendSemicolon$ef52943abec52244)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;
	jboolean	(*appendSemicolon$3eee72f89e285cad)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, jboolean) _JC_JCNI_ATTR;
	void	(*print$be8fd119cbff90e9)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *) _JC_JCNI_ATTR;
	void	(*printAst$501fe41e7ed32dd4)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *) _JC_JCNI_ATTR;
	jboolean	(*printType$a652b156b81ce22a)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;
	jboolean	(*printType$9f92289ce5818d49)(_jc_env *, struct _jc_polyglot_visit_PrettyPrinter$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_PrettyPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_PrettyPrinter$vmethods	polyglot_visit_PrettyPrinter;
};

// Vtype
struct _jc_polyglot_visit_PrettyPrinter$vtype {
	_jc_type			type;
	_jc_polyglot_visit_PrettyPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_PrettyPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_PrettyPrinter$refs {
    _jc_polyglot_visit_PrettyPrinter$sub_refs	polyglot_visit_PrettyPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_PrettyPrinter$sub_nonrefs {
	jboolean	appendSemicolon;
	jboolean	printType;
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_PrettyPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_PrettyPrinter$sub_nonrefs	polyglot_visit_PrettyPrinter;
};

// Object instance structure
struct _jc_polyglot_visit_PrettyPrinter$object {
	_jc_polyglot_visit_PrettyPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_PrettyPrinter$vtype	*vtype;
	_jc_polyglot_visit_PrettyPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_PrettyPrinter$vtype _jc_polyglot_visit_PrettyPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_PrettyPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_PrettyPrinter$class_object;

#endif	/* _JC_polyglot_visit_PrettyPrinter_H_ */
